@@ -1,11 +1,10 @@
-"""CLI entry points of faddr."""
+"""CLI entry point for database creation."""
 
 import argparse
 import sys
 
-from rich.console import Console
-
-from faddr import logger
+from faddr import console, logger
+from faddr.database import Database
 from faddr.exceptions import FaddrParserUnknownProfile, FaddrSettingsFileFormatError
 from faddr.parser import Parser
 from faddr.rancid import RancidDir, RancidGroup
@@ -35,9 +34,6 @@ def parse_cmd_args():
 def main():
     """Parsing devices' config files and writing data to database."""
 
-    # Setup rich console for pretty printing
-    console = Console()
-
     cmd_args = parse_cmd_args()
     logger.debug(f"Arguments from CMD: {cmd_args}")
 
@@ -48,6 +44,9 @@ def main():
         sys.exit(1)
     logger.debug(f"Generated settings: {settings.dict()}")
 
+    database = Database(**settings.database.dict())
+    database.new()
+
     for rancid_dir in settings.rancid.dirs:
         if rancid_dir.kind == "dir":
             rancid = RancidDir(rancid_dir.path)
@@ -64,6 +63,17 @@ def main():
                     settings.templates_dir,
                 )
                 data = parser.parse()
-                console.print(data)
+                device = {
+                    "info": {
+                        "path": str(config["path"]),
+                        "name": str(config["name"]),
+                        "source": "rancid",
+                    }
+                }
+                device.update(data)
+                database.insert_device(device)
+                console.print(device)
             except FaddrParserUnknownProfile:
                 logger.debug(f"Unsupported config: {config}")
+
+    database.set_default()
